from .eq5d3l_form import Eq5d3lForm, Eq5d3lFormValidator
from .icecapa_form import IcecapaForm, IcecapaFormValidator
from .sf12_form import Sf12Form, Sf12FormValidator


__all__ = [
    "Eq5d3lForm",
    "Eq5d3lFormValidator",
    "IcecapaForm",
    "IcecapaFormValidator",
    "Sf12Form",
    "Sf12FormValidator",
]



from .eq5d3l_model_mixin import Eq5d3lModelMixin
from .icecapa_model_mixin import IcecapaModelMixin
from .sf12_model_mixin import Sf12ModelMixin


__all__ = ["Eq5d3lModelMixin", "IcecapaModelMixin", "Sf12ModelMixin"]



# Generated by Django 4.2.1 on 2023-07-05 02:16

import django.db.models.manager
import edc_sites.models
from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("edc_qol", "0005_alter_historicalicecapa_enjoyment_and_more"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="eq5d3l",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "get_latest_by": "modified",
                "ordering": ("-modified", "-created"),
                "verbose_name": "EuroQol EQ-5D-3L Instrument",
                "verbose_name_plural": "EuroQol EQ-5D-3L Instrument",
            },
        ),
        migrations.AlterModelOptions(
            name="icecapa",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "get_latest_by": "modified",
                "ordering": ("-modified", "-created"),
                "verbose_name": "Overall quality of life (ICECAP-A V2)",
                "verbose_name_plural": "Overall quality of life (ICECAP-A V2)",
            },
        ),
        migrations.AlterModelOptions(
            name="sf12",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "get_latest_by": "modified",
                "ordering": ("-modified", "-created"),
                "verbose_name": "SF-12 Health Survey",
                "verbose_name_plural": "SF-12 Health Survey",
            },
        ),
        migrations.AlterModelManagers(
            name="eq5d3l",
            managers=[
                ("on_site", edc_sites.models.CurrentSiteManager()),
                ("objects", django.db.models.manager.Manager()),
            ],
        ),
        migrations.AlterModelManagers(
            name="icecapa",
            managers=[
                ("on_site", edc_sites.models.CurrentSiteManager()),
                ("objects", django.db.models.manager.Manager()),
            ],
        ),
        migrations.AlterModelManagers(
            name="sf12",
            managers=[
                ("on_site", edc_sites.models.CurrentSiteManager()),
                ("objects", django.db.models.manager.Manager()),
            ],
        ),
    ]
